pub struct BlockWeightsCache { /* private fields */ }Expand description
A cache used to calculate block weight limits, the effective median and long term block weights.
These calculations require a lot of data from the database so by caching this data it reduces the load on the database.
Implementations
Sourceimpl BlockWeightsCache
impl BlockWeightsCache
Sourcepub async fn init_from_chain_height<D: Database + Clone>(
chain_height: usize,
config: BlockWeightsCacheConfig,
database: D,
chain: Chain,
) -> Result<Self, ContextCacheError>
pub async fn init_from_chain_height<D: Database + Clone>( chain_height: usize, config: BlockWeightsCacheConfig, database: D, chain: Chain, ) -> Result<Self, ContextCacheError>
Initialize the BlockWeightsCache at the the given chain height.
Sourcepub async fn pop_blocks_main_chain<D: Database + Clone>(
&mut self,
numb_blocks: usize,
database: D,
) -> Result<(), ContextCacheError>
pub async fn pop_blocks_main_chain<D: Database + Clone>( &mut self, numb_blocks: usize, database: D, ) -> Result<(), ContextCacheError>
Pop some blocks from the top of the cache.
The cache will be returned to the state it would have been in numb_blocks ago.
Sourcepub fn new_block(
&mut self,
block_height: usize,
block_weight: usize,
long_term_weight: usize,
)
pub fn new_block( &mut self, block_height: usize, block_weight: usize, long_term_weight: usize, )
Add a new block to the cache.
The block_height MUST be one more than the last height the cache has
seen.
Sourcepub fn median_long_term_weight(&self) -> usize
pub fn median_long_term_weight(&self) -> usize
Returns the median long term weight over the last LONG_TERM_WINDOW blocks, or custom amount of blocks in the config.
Sourcepub fn median_short_term_weight(&self) -> usize
pub fn median_short_term_weight(&self) -> usize
Returns the median weight over the last SHORT_TERM_WINDOW blocks, or custom amount of blocks in the config.
Sourcepub fn effective_median_block_weight(&self, hf: HardFork) -> usize
pub fn effective_median_block_weight(&self, hf: HardFork) -> usize
Returns the effective median weight, used for block reward calculations and to calculate the block weight limit.
Sourcepub fn median_for_block_reward(&self, hf: HardFork) -> usize
pub fn median_for_block_reward(&self, hf: HardFork) -> usize
Returns the median weight used to calculate block reward punishment.
https://cuprate.github.io/monero-book/consensus_rules/blocks/reward.html#calculating-block-reward
Sourcepub fn fee_estimate_2021(
&self,
grace_blocks: u64,
hf: HardFork,
already_generated_coins: u64,
) -> Result<FeeEstimate, BoxError>
pub fn fee_estimate_2021( &self, grace_blocks: u64, hf: HardFork, already_generated_coins: u64, ) -> Result<FeeEstimate, BoxError>
Computes the 2021 fee estimates.